@@ -1,19 +1,27 @@
 package Glitch;
-
-use 5.006;
-use strict;
-use warnings;
-use Data::Dumper;
-our %GLITCHES;
+our $VERSION = '0.03';
+use 5.006; use strict; use warnings;
+use Data::Dumper; use feature qw/state/;
+state %GLITCHES;
 
 BEGIN {
         $Data::Dumper::Deparse = 1;
 }
 
 sub import {
-	my $package = caller();
-	no strict 'refs';
-	*{"${package}::glitch"} = \&glitch;
+	my ($pkg, %import) = @_;
+	if (keys %import) {
+		_build_glitch(
+			name => $_,
+			%{ $import{$_} },
+			map { $_ => '' } ("file", "filepath", "line", "stacktrace", "module")
+		) for sort keys %import;
+	}
+	do {
+		no strict 'refs';
+		my $package = caller();
+		*{"${package}::glitch"} = \&glitch;
+	};
 }
 
 sub glitch {
@@ -31,9 +39,9 @@ sub glitch {
 sub _build_glitch {
 	my (%options) = @_;
 	my $class = sprintf q|%s::%s|, $options{object_name} ||= 'Glitch', $options{name};
-	my @methods = map { my $struct = $_ =~ m/file|filepath|line|stacktrace/ ? "''" :  _stringify_struct($options{$_}); "sub $_ { return \$_[0]->{$_} || $struct; }" } sort keys %options;
+	my @methods = map { my $struct = $_ =~ m/(file|filepath|line|stacktrace|module)/ ? "''" :  _stringify_struct($options{$_}); "sub $_ { return \$_[0]->{$_} || $struct; }" } sort keys %options;
 	unshift @methods, 'sub new { my $self = shift; return bless {@_}, $self; }';
-	push @methods, 'sub stringify { return ($_[0]->{message} || "") . " at " . $_[0]->{filepath} . " line " . $_[0]->{line} . "\n"; }';
+	push @methods, 'sub stringify { return $_[0]->message . " at " . $_[0]->filepath . " line " . $_[0]->line . "\n"; }';
 	my $package = sprintf(q|package %s;
 use overload '""' => \&stringify;
 %s
@@ -84,21 +92,86 @@ Glitch - Exception Handling.
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
-
 =head1 SYNOPSIS
 
+	package Foo;
+
 	use Glitch;
 
-	do { ... } or glitch('one', message => 'Create a new glitch error message');
+	sub bar {
+		do { ... } or glitch('one', message => 'Create a new glitch error message');
 
-	...
+		... later in your code you can then reuse glitch 'one'
 
-	do { ... } or glitch('one'); 
+		do { ... } or glitch('one');
+	}
+
+...
+
+	package Foo;
+
+	use Glitch (
+		one => {
+			message => 'Create a new glitch error message'
+		},
+		two => {
+			message => 'A different glitch error message',
+			fileName => '',
+		}
+	);
+
+	sub bar {
+		eval {
+			do { ... } or glitch('one');
+			...
+			do { ... } or glitch('two', fileName => 'abc');
+		};
+		if ($@) {
+			do { ... } if $@->name == 'one';
+			do { ... } if $@->name == 'two';
+		}
+	}
+
+	1;
+
+...
+
+	package Glitches;
+
+	use Glitch (
+		one => {
+			message => 'Create a new glitch error message'
+		},
+		two => {
+			message => 'A different glitch error message',
+			fileName => '',
+		}
+	);
+
+	1;
+
+	package Foo;
+
+	use Glitch;
+	use Glitches;
+
+	sub bar {
+		eval {
+			do { ... } or glitch('one');
+			...
+			do { ... } or glitch('two', fileName => 'abc');
+		};
+		if ($@) {
+			if ($@->name == 'one') { ... }
+			elsif ($@->name == 'two') { ... }
+		}
+	}
+
+	1;
 
 =head1 EXPORT
 
